kombu.transport.virtual.scheduling — Kombu v1.3.2 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »

- kombu.transport.virtual.scheduling

# kombu.transport.virtual.scheduling

Consumer utilities.

copyright: | 2009 - 2011 by Ask Solem.
license: | BSD, see LICENSE for more details.

class `kombu.transport.virtual.scheduling.` `FairCycle`(fun, resources, predicate=<type 'exceptions.Exception'>)

  Consume from a set of resources, where each resource gets an equal chance to be consumed from.

  `close`()
  `get`(**kwargs)

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v1.3.2 documentation »
- API Reference »